@@ -4,22 +4,21 @@ import json
 from typing import Dict, List, Optional, Set, Tuple
 
 import codefast as cf
-from authc import get_redis
-
+import redis 
 
 class Base(object):
     pass
 
 
-class _Queue(object):
+class Messager(object):
     def post(self, msg: Dict):
         pass
 
 
-class MessageQueue(_Queue):
+class MessageQueue(Messager):
     def __init__(self) -> None:
         super().__init__()
-        self.queue = get_redis()
+        self.queue = redis.Redis(host='localhost', port=6379, db=0)
         self.name = '__MessageQUEUE__'
 
     def post(self, msg: Dict):
@@ -44,7 +43,7 @@ class MessageQueue(_Queue):
 
 
 class EventReporter(object):
-    def __init__(self, messager: _Queue) -> None:
+    def __init__(self, messager: Messager) -> None:
         self.messager = messager
 
     def report(self, msg: Dict) -> bool:
@@ -53,14 +52,18 @@ class EventReporter(object):
 
 class TaskReporter(EventReporter):
     def __init__(self, task_name: str,
-                 messager: _Queue = MessageQueue()) -> None:
+                 messager: Messager = MessageQueue()) -> None:
         super().__init__(messager)
         self.task_name = task_name
 
     def collect_info(self) -> dict:
         hostname = cf.shell('hostname')
         date = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
-        return {'task_name': self.task_name, 'hostname': hostname, 'date': date}
+        return {
+            'task_name': self.task_name,
+            'hostname': hostname,
+            'date': date
+        }
 
 
 def report_self(name: str) -> bool:
@@ -72,5 +75,15 @@ def report_self(name: str) -> bool:
     tr.report(tr.collect_info())
 
 
+def report_self_cli() -> bool:
+    """
+    """
+    import sys
+    name = sys.argv[1]
+    cf.info('report self: {}'.format(name))
+    report_self(name)
+    cf.info('report self done.')
+
+
 if __name__ == '__main__':
     pass
