@@ -69,7 +69,9 @@ class MarkPosted(Component):
 
 
 def logtrack(log_path: str = '/tmp/cf.log'):
-    pass
+    p = Pipeline([NewErrorCollector(), Post(), MarkPosted()])
+    p.process(log_path)
+
 
 def looplogtrack(log_path: str = '/tmp/cf.log', interval: int = 60):
     p = Pipeline([NewErrorCollector(), Post(), MarkPosted()])
